# DGLAB-python-driver
 PyDGLAB - A Third-party DGLAB Python Driver
 
 **注意：目前这仍然是一个未完成的模块，请在使用前自行斟酌。**
 
 **CAUTION: This module is still under development. Think before use.**

 Check demo.py for more info.